##  Adding Applications
In order to include the application fact sheets from the inventory in your diagrams, do the following:
  1. Click on "+" icon in the toolbar. Alternatively, you can also right-click anywhere on the canvas and choose Insert from Inventory.
  2. A window will open showing all the application fact sheets from the inventory. Make use of filters to choose the fact sheets needed by using the check box to the left and clicking Insert selected. In this instance, the application HR Admin. One also has the option to insert all of the fact sheets by clicking on Insert all.
  3. Selected fact sheets are now presented in the canvas.

![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2755ac327a441014899ff95d7f37f5f2_LowRes.gif)
To understand the dependencies of this application, including both direct and indirect ones, you can expand the interfaces.
